# yaml-combine-py

A YAML pre-processor to combine one or more YAML files with `$xref` references.

Link to this project at pypi: [https://pypi.org/project/yaml-combine/](https://pypi.org/project/yaml-combine/)

This project is compatible with the merging algorithm used in [swagger-combine-maven-plugin][swagger-combine-maven-plugin-github].

See [the maven plugin site documentation][swagger-combine-maven-plugin] for a description of `$xref` references and examples.

[swagger-combine-maven-plugin-github]: https://github.com/randomnoun/swagger-combine-maven-plugin
[swagger-combine-maven-plugin]: https://randomnoun.github.io/swagger-combine-maven-plugin/
